==> qt-creator-opensource-src-4.0.2.zip: qt-creator-opensource-src-4.0.2/src/plugins/debugger/stackwindow.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef DEBUGGER_STACKWINDOW_H
#define DEBUGGER_STACKWINDOW_H

#include <utils/basetreeview.h>
#include <QCoreApplication>

namespace Debugger {
namespace Internal {

class StackTreeView : public Utils::BaseTreeView
{
    Q_DECLARE_TR_FUNCTIONS(Debugger::Internal::StackTreeView)
public:
    StackTreeView();

private:
    void rowActivated(const QModelIndex &index);
    void setModel(QAbstractItemModel *model);
    void contextMenuEvent(QContextMenuEvent *ev);

    void showAddressColumn(bool on);
    void reloadFullStack();
    void copyContentsToClipboard();
};

} // namespace Internal
} // namespace Debugger

#endif // DEBUGGER_STACKWINDOW_H

==> qt-creator-opensource-src-4.1.0.zip: qt-creator-opensource-src-4.1.0/src/plugins/debugger/stackwindow.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <utils/basetreeview.h>
#include <QCoreApplication>

namespace Debugger {
namespace Internal {

class StackTreeView : public Utils::BaseTreeView
{
    Q_DECLARE_TR_FUNCTIONS(Debugger::Internal::StackTreeView)
public:
    StackTreeView();

private:
    void rowActivated(const QModelIndex &index);
    void setModel(QAbstractItemModel *model);
    void contextMenuEvent(QContextMenuEvent *ev);

    void showAddressColumn(bool on);
    void reloadFullStack();
    void copyContentsToClipboard();
};

} // namespace Internal
} // namespace Debugger
